==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/pt_BR.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registro",
    "Errors in the log" : "Erros no log",
    "Failed to get an iterator for log entries: %s" : "Falha ao obter um iterador para entradas de log: %s",
    "No errors in the logs since %s" : "Sem erros no logo desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erro nos logs desde %s","%n erros nos logs desde %s","%n erros nos logs desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n alerta nos logs desde %s","%n alertas nos logs desde %s","%n alertas nos logs desde %s"],
    "Log Reader" : "Leitor de Registro",
    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se você acha que isso é um erro, verifique {setting} em seu {config} e verifique o Manual de administração do Nextcloud.",
    "Log reader" : "Leitor de log",
    "Open log reader settings" : "Abra as configurações do leitor de log",
    "Log reader settings" : "Configurações do leitor de log",
    "Currently the log file {file} is shown" : "Atualmente, o arquivo de log {file} é mostrado",
    "Show server log" : "Mostrar registro do servidor",
    "Live view is disabled" : "A visualização ao vivo está desativada",
    "No log file" : "Nenhum arquivo de log",
    "File-based logging must be enabled to access logs from the Web UI." : "O log baseado em arquivo deve ser ativado para acessar os logs da IU da Web.",
    "Log entry successfully copied" : "Entrada de registro copiada com sucesso",
    "Level" : "Nível",
    "App" : "Aplicativo",
    "No app in context" : "Nenhum aplicativo no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada bruta",
    "Copy formatted entry" : "Copiar entrada formatada",
    "Hide exception details" : "Ocultar detalhes da exceção",
    "View exception details" : "Ver detalhes da exceção",
    "Raw log entry" : "Entrada de registro bruto",
    "Search log entries" : "Pesquisar entradas de registro",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Linha {line}",
    "Filter log levels" : "Filtrar níveis de registro",
    "Set log level" : "Definir nível de registro",
    "Time format" : "Formato de hora",
    "Live view" : "Visualização ao vivo",
    "Download/Upload logs" : "Baixar/carregar registros",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Não foi possível analisar o arquivo de log local",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Você também pode mostrar entradas de registro copiadas da sua área de transferência colando-as na visualização de registro usando: {keyboardShortcut}",
    "Download logs" : "Registro de downloads",
    "Show local log file" : "Mostrar arquivo de log local",
    "Upload local log file to be displayed" : "Carregue o arquivo de log local a ser exibido",
    "Time format used for displaying the timestamp" : "Formato de hora usado para exibir o carimbo de data/hora",
    "(Local log files only support the \"raw\" time format)" : "(Os arquivos de log locais suportam apenas o formato de hora \"bruto\")",
    "Could not change date time format." : "Não foi possível alterar o formato de data e hora.",
    "Raw data" : "Dados não tratados",
    "Local time" : "Horário local",
    "UTC time" : "Tempo UTC",
    "Relative" : "Relativo",
    "Could not change live view setting." : "Não foi possível alterar a configuração de exibição ao vivo.",
    "Polling is disabled because server is not configured to log to file" : "A votação está desativada porque o servidor não está configurado para registrar no arquivo",
    "Polling (live view)" : "Votação (exibição ao vivo)",
    "Could not set logging levels to show" : "Não foi possível definir os níveis de registro para mostrar",
    "Filter logging levels" : "Filtrar níveis de registro",
    "Could not set logging level" : "Não foi possível definir o nível de registro",
    "Set backend loglevel" : "Definir nível de log de back-end",
    "Application" : "Aplicativo",
    "Message" : "Mensagem",
    "Log entry actions" : "Ações de entrada de registro",
    "Loading older log entries" : "Carregando entradas de log mais antigas",
    "No older log entries available" : "Nenhuma entrada de registro mais antiga disponível",
    "Collapse row" : "Recolher linha",
    "Expand row" : "Expandir linha",
    "Show details" : "Exibir detalhes",
    "Debug" : "Depurar ",
    "Info" : "Informações ",
    "Warning" : "Aviso",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Não foi possível carregar entradas dos logs",
    "Clipboard" : "Prancheta",
    "Could not parse clipboard content" : "Não foi possível analisar o conteúdo da área de transferência",
    "Could not fetch new log entries (server unavailable)" : "Não foi possível buscar novas entradas de log (servidor indisponível)",
    "Could not fetch new entries" : "Não foi possível obter novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Não foi possível copiar para a área de transferência, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} às {time}\n"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/logreader/l10n/pt_BR.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registro",
    "Errors in the log" : "Erros no log",
    "Failed to get an iterator for log entries: %s" : "Falha ao obter um iterador para entradas de log: %s",
    "No errors in the logs since %s" : "Sem erros nos logs desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erro nos logs desde %s","%n erros nos logs desde %s","%n erros nos logs desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n aviso nos logs desde %s","%n avisos nos logs desde %s","%n avisos nos logs desde %s"],
    "Log Reader" : "Leitor de Registro",
    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Se você acha que isso é um erro, verifique {setting} em seu {config} e verifique o Manual de administração do Nextcloud.",
    "Log reader" : "Leitor de log",
    "Open log reader settings" : "Abra as configurações do leitor de log",
    "Log reader settings" : "Configurações do leitor de log",
    "Currently the log file {file} is shown" : "Atualmente, o arquivo de log {file} é mostrado",
    "Show server log" : "Mostrar log do servidor",
    "Live view is disabled" : "A visualização ao vivo está desativada",
    "No log file" : "Nenhum arquivo de log",
    "File-based logging must be enabled to access logs from the Web UI." : "O log baseado em arquivo deve ser ativado para acessar os logs da IU da Web.",
    "Log entry successfully copied" : "Entrada de log copiada com sucesso",
    "Level" : "Nível",
    "App" : "Aplicativo",
    "No app in context" : "Nenhum aplicativo no contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada bruta",
    "Copy formatted entry" : "Copiar entrada formatada",
    "Hide exception details" : "Ocultar detalhes da exceção",
    "View exception details" : "Ver detalhes da exceção",
    "Raw log entry" : "Entrada de log bruta",
    "Search log entries" : "Pesquisar entradas de log",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Linha {line}",
    "Filter log levels" : "Filtrar níveis de log",
    "Set log level" : "Definir nível de log",
    "Time format" : "Formato de hora",
    "Live view" : "Visualização ao vivo",
    "Download/Upload logs" : "Fazer download/upload dos logs",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Não foi possível analisar o arquivo de log local",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Você também pode mostrar entradas de registro copiadas da sua área de transferência colando-as na visualização de registro usando: {keyboardShortcut}",
    "Download logs" : "Registro de downloads",
    "Show local log file" : "Mostrar arquivo de log local",
    "Upload local log file to be displayed" : "Carregue o arquivo de log local a ser exibido",
    "Time format used for displaying the timestamp" : "Formato de hora usado para exibir a marca temporal",
    "(Local log files only support the \"raw\" time format)" : "(Os arquivos de log locais suportam apenas o formato de hora \"bruto\")",
    "Could not change date time format." : "Não foi possível alterar o formato de data e hora.",
    "Raw data" : "Dados brutos",
    "Local time" : "Horário local",
    "UTC time" : "Horário UTC",
    "Relative" : "Relativo",
    "Could not change live view setting." : "Não foi possível alterar a configuração da visualização ao vivo.",
    "Polling is disabled because server is not configured to log to file" : "A polling está desativada porque o servidor não está configurado para registrar em arquivo",
    "Polling (live view)" : "Polling (visualização ao vivo)",
    "Could not set logging levels to show" : "Não foi possível definir os níveis de log da visualização",
    "Filter logging levels" : "Filtrar níveis de log",
    "Could not set logging level" : "Não foi possível definir o nível de log",
    "Set backend loglevel" : "Definir nível de log de back-end",
    "Application" : "Aplicativo",
    "Message" : "Mensagem",
    "Log entry actions" : "Ações de entradas de log",
    "Loading older log entries" : "Carregando entradas de log mais antigas",
    "No older log entries available" : "Nenhuma entrada de log mais antiga disponível",
    "Collapse row" : "Recolher linha",
    "Expand row" : "Expandir linha",
    "Show details" : "Exibir detalhes",
    "Debug" : "Depuração",
    "Info" : "Informação",
    "Warning" : "Aviso",
    "Error" : "Erro",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Não foi possível carregar entradas de log",
    "Clipboard" : "Área de transferência",
    "Could not parse clipboard content" : "Não foi possível analisar o conteúdo da área de transferência",
    "Could not fetch new log entries (server unavailable)" : "Não foi possível obter novas entradas de log (servidor indisponível)",
    "Could not fetch new entries" : "Não foi possível obter novas entradas",
    "Could not copy to clipboard, please copy manually:" : "Não foi possível copiar para a área de transferência, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} às {time}\n"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
